aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/python/kernel_tests/pool_test.py
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/python/kernel_tests/pool_test.py')
-rw-r--r--tensorflow/python/kernel_tests/pool_test.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tensorflow/python/kernel_tests/pool_test.py b/tensorflow/python/kernel_tests/pool_test.py
index 8136efe936..79450c3f70 100644
--- a/tensorflow/python/kernel_tests/pool_test.py
+++ b/tensorflow/python/kernel_tests/pool_test.py
@@ -232,8 +232,8 @@ class PoolingTest(tf.test.TestCase):
strides=strides)
def testPoolNC(self):
- if tf.test.is_gpu_available():
- # "NC*" format is not currently supported on CPU.
+ if tf.test.is_gpu_available(cuda_only=True):
+ # "NC*" format is currently only supported on CUDA.
with self.test_session(use_gpu=True):
for padding in ["SAME", "VALID"]:
self._test(input_shape=[2, 2, 9],